%define releasebase 1
# needed for opeblas make and naming
# define %processor based on OpenBLAS TargetList.txt. This can be changed
# for other processors as needed, set %cpuname to name used for
# processor, this will be used in path and RPM name.
%define processor HASWELL 
%define cpuname haswell
%define nbase openblas
%define prefix /opt/blas/%{nbase}/%{version}/%{compilertag}/%{cpuname}
%define _libdir %{prefix}/lib
%define modulepath /opt/Modules/modulefiles/%{nbase}/%{version}/%{compilertag}
%define unpackname xianyi-OpenBLAS-aceee4e
%define sourcename xianyi-OpenBLAS-v0.2.13-0-g51ce5ef.tar.gz

# NOTE: compilers are mutually exclusive, only set one,
#       if not using command line options
#       !not all compilers have been implemented and tested!
%define use_gnu4  1
%define use_gnu3 0
%define use_pgi  0
%define use_intel 0
%define use_pathsc 0
# allow --with[out] <feature> at rpm command line build
%{?_with_gnu3: %{expand: %%define use_gnu3 1}}
%{?_with_gnu4: %{expand: %%define use_gnu4 1}}
%{?_with_pgi: %{expand: %%define use_pgi 1}}
%{?_with_intel: %{expand: %%define use_intel 1}}
%{?_with_pathsc: %{expand: %%define use_pathsc 1}}
%{?_with_basement: %{expand: %%define as_basement 1}}
%{?_with_limulus: %{expand: %%define as_limulus 1}}
#pick the target
%if "1" == "%{as_basement}"
%define targetbase Basement
%else
%define targetbase Limulus
%endif

Summary: OpenBLAS libraries for numerical linear algebra.
Group: %{targetbase}/Libraries
Release: %{releasebase}.%{targetbase}
Version: 0.2.13
License: Freely distributable
URL: http://xianyi.github.com/OpenBLAS/
Packager: deadline@basement-supercomputing.com
Vendor: Basement Supercomputing.com
Source: %{sourcename}
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Requires: modules

%global _compiler_load  module load %{compilertag}
%global _compiler_unload  module unload %{compilertag}

# is there a better way to do this?
%if "1" == "%{use_pgi}"
echo "PGI Comp not implemented"
exit 1
%define compilertag pgi
%define fcompiler pg77
%define fcompiler-opts
%define ccompiler pgcc
%else
%if "1" == "%{use_intel}"
%define compilertag intel
%define fcompiler ifort
%define fcompiler-opts "-fast"
%define ccompiler icc
%else
%if "1" == "%{use_pathsc}"
echo "Pathscale Comp not implemented"
exit 1
Name: %{nbase}-pathsc
%define compilertag pathsc
%else
%if "1" == "%{use_gnu3}"
%define compilertag gnu3 
%define fcompiler g77
%define fcompiler_opts_static "-O2"
%define fcompiler_opts_shared "-O2 -fPIC"
%define ccompiler gcc
%else
#default
%define compilertag gnu4
%define fcompiler gfortran
%define fcompiler_opts_static "-O2"
%define fcompiler_opts_shared "-O2 -fPIC"
%define ccompiler gcc
%endif
%endif
%endif
%endif

Name: %{nbase}-%{compilertag}-%{cpuname}


%description
OpenBLAS is an optimized BLAS library based on GotoBLAS2 1.13 BSD version. OpenBLAS is an open source project supported by Lab of Parallel Software and Computational Science, ISCAS. 



%prep
%setup -n %{unpackname}

%build
rpm -qf /opt/Modules/bin/modulecmd >& /dev/null
if [ $? -ne 0 ]; then
  echo "This RPM requries the BSC Modules package to build"
  exit 1
fi
. /etc/profile.d/modules.sh
# there is no module for gnu4, gnu3, these are default
# the module command just fails to load these module
# and continues with the gnu compilers, a bit ugly but it works
%{_compiler_load}
# need to make a devtoolset module
. /opt/rh/devtoolset-2/enable

make TARGET=%{processor} 
%{_compiler_unload}

%install
make PREFIX=%{buildroot}/%{prefix} install
#fix the symlinks
BACK=`pwd`
cd %{buildroot}/%{prefix}/lib
/bin/rm libopenblas.a
/bin/rm libopenblas.so 
/bin/rm libopenblas.so.0
/bin/ln -s libopenblas_%{cpuname}p-r%{version}.a libopenblas.a 
/bin/ln -s libopenblas_%{cpuname}p-r%{version}.so libopenblas.so
/bin/ln -s libopenblas_%{cpuname}p-r%{version}.so libopenblas.so.0
cd $BACK
# put all the Goto files in one directory
/bin/mkdir -p GotoBLAS
/bin/cp GotoBLAS*.txt GotoBLAS
# fix BUILDROOT in files
sed --in-place 's!%{buildroot}!!'  %{buildroot}/%{prefix}/cmake/OpenBLASConfig.cmake
# create /opt//etc/ld.so.conf.d/
echo "Creating /opt//etc/ld.so.conf.d/%{name} file"
mkdir -p %{buildroot}/opt/etc/ld.so.conf.d
cat <<EOF> %{buildroot}/opt/etc/ld.so.conf.d/%{name}-%{version}.conf
%{_libdir}
EOF


#create the module file
mkdir -p %{buildroot}/%{modulepath}
cat <<EOF >%{buildroot}/%{modulepath}/%{cpuname}
#%Module1.0#######################################################################
## %{nbase} modulefile
##

proc ModulesHelp { } {
        puts stderr "\tThis module loads the appropriate environment for "
        puts stderr "\tusing %{name} version %{version}.\n"
}

module-whatis "%{name} %{version}"
module-log error none

set openblasroot %{prefix}

if [ module-info mode load ] {
  prepend-path  LD_LIBRARY_PATH \$openblasroot/lib
	setenv OPENBLAS_PATH \$openblasroot/lib
	setenv OPENBLAS_INCLUDE \$openblasroot/include
}
if [ module-info mode remove ] {
  remove-path LD_LIBRARY_PATH \$openblasroot/lib
	unsetenv OPENBLAS_PATH 
	unsetenv OPENBLAS_INCLUDE
}
EOF
%post
/sbin/ldconfig 2>/dev/null

%postun
/sbin/ldconfig 2>/dev/null

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README.md GotoBLAS  reference
%{prefix}
%{modulepath}/%{cpuname}
/opt/%{_sysconfdir}/ld.so.conf.d/%{name}-%{version}.conf

%changelog
* Tue Jan 27 2015  Douglas Eadline <deadline@basement-supercomputing.com>
- removed %{buildroot} from cmake file 
* Fri Dec 12 2012  Douglas Eadline <deadline@basement-supercomputing.com>
- added /opt/etc/ld.so.conf.d entry
* Tue Sep 25 2012 - Douglas Eadline <deadline@eadline.org>
- initial build

